@@ -96,7 +96,7 @@ personal_nlu = {
         'score': 10.0,
         'state': 'move_on_request',
 
-        '`Alright. So, `': 'SYSTEM:root'
+        '`Alright. `': 'SYSTEM:root'
     },
 
     # transition to travel
@@ -159,7 +159,7 @@ personal_nlu = {
     '[{virus,disease,illness},{china,chinese,wuhan,global,widespread,pandemic,epidemic}],'
     'virtual reality, vr, v r,oculus,vive,rift,morpheus)'
     '{'
-    '[! #NOT(not) [{let us, we, you, can you, can we, could you, could we}] {talk, converse, conversation, discuss, discussion, chat} about? $topic_requested=/.*/]'
+    '[! #NOT(not) [{let us, we, you, can you, can we, could you, could we}] {talk, converse, conversation, discuss, discussion, chat} about $topic_requested=/.+/]'
     '}':{
         'score': 9.0,
         'hop': 'True',
@@ -274,12 +274,12 @@ personal_nlu = {
 
                             #todo - what if user asks for another one
 
-                            '#GRET': 'exit'
+                            '#GRET': 'SYSTEM:root'
                         }
                     }
                 },
 
-                '#UNX': {
+                '#UNX(None)': {
                     'state': 'joke_unx',
 
                     '`He just needed a little space!`': 'joke_given'
@@ -290,7 +290,7 @@ personal_nlu = {
         '/.*/ #SCORE(0.9)':{
             'state': 'multi_joke',
 
-            '`Oh, I\'m sorry. I seem to only remember the one joke I already told you. ` #GRET': 'exit'
+            '`Oh, I\'m sorry. I seem to only remember the one joke I already told you. ` #GRET': 'SYSTEM:root'
         }
     },
 
@@ -310,7 +310,7 @@ personal_nlu = {
         '`That\'s so nice of you to say. I am really enjoying talking to you.`' :{
             'state': 'user_likes_emora_r',
 
-            '#UNX': {'#GRET': 'exit'}
+            '#UNX': {'#GRET': 'SYSTEM:root'}
         }
     },
 
@@ -376,6 +376,62 @@ personal_nlu = {
     #
     # },
 
+    '[{do you know, remember, what, whats, tell me, ask} my name]': {
+        'state': 'test_user_name',
+
+        '`It\'s` $username `, right?`': {
+
+            '#UNX': {
+
+                '#GRET': 'SYSTEM:root'
+            },
+
+            '{#DISAGREE,wrong,incorrect,false,is not}': {
+
+                '`Oh, my bad. I was so sure you were` $username `, I\'m sorry. What is your name then?`'
+                '#SET($username=None)': {
+                    'state': 'get_user_name',
+
+                    '{' 
+                    '[$username=#ONT(_names)], ' 
+                    '[! #ONT_NEG(_names), [name, is, $username=alexa]],' 
+                    '[! my, name, is, $username=alexa],' 
+                    '[! {can,may,should}, call, me, $username=alexa]' 
+                    '}': {
+
+                        '$username `? I\'ll try to remember that.`': {
+
+                            '#DISAGREE'
+                            '#SET($username=None)': {
+                                'state': 'cant_hear_name',
+
+                                '`Oh no! I think I\'m having trouble getting your name right. '
+                                'Sometimes I can\'t hear certain names properly through the microphone, so I hope you '
+                                'don\'t take it personally.`': {
+
+                                    '#UNX(Sorry about it.)': {'#GRET': 'SYSTEM:root'}  # expand
+                                }
+                            },
+
+                            '#UNX': {'#GRET': 'SYSTEM:root'}
+                        }
+                    },
+
+                    '#UNX(None)': 'cant_hear_name'
+                }
+            },
+
+            '#NOT(not) [{#AGREE, it is, right, correct, true}]': {
+
+                '`You think I wouldn\'t remember your name? Anyway,` #GRET': 'SYSTEM:root'
+            }
+        },
+
+        '`Hmm. I don\'t seem to remember your name. What would you like me to call you?`'
+        '#UNSET(username)':
+            'get_user_name'
+    }
+
     ### Topic specific #########################################
 
     # # Have you seen ___
