@@ -43,15 +43,6 @@ cdf.add_system_transition('life_opening', 'reading:start', '')
 cdf.add_system_transition('life_opening', 'root', '', score=0.0)
 cdf.controller().update_state_settings('life_opening', system_multi_hop=True)
 
-cdf.add_state('movies_intro')
-cdf.add_state('music_intro')
-cdf.add_state('sports_intro')
-cdf.add_state('virtual_reality_intro')
-cdf.add_state('pet_intro')
-cdf.add_state('travel_intro')
-cdf.add_state('external_news_intro')
-cdf.add_state('coronavirus_op_intro')
-
 for component in cdf.components():
     component.load_global_nlu(personal_nlu)
     component.load_update_rules(global_update_rules)
@@ -59,4 +50,4 @@ for component in cdf.components():
 
 if __name__ == '__main__':
     #emora.precache_transitions()
-    cdf.run(debugging=False)
\ No newline at end of file
+    cdf.run(debugging=True)
\ No newline at end of file
