@@ -1,6 +1,5 @@
 import json, os, nltk
 from collections import defaultdict
-from data.existing_dict import d, e
 
 def handle_punc(ls):
     new_ls = []
@@ -156,7 +155,7 @@ if __name__ == '__main__':
     ont.merge_dict("_old_life stage", get_dict_from_list, os.path.join(PATH, "life_stage.txt"), "stage")
     ont.merge_dict("_school subject", get_dict_from_list, os.path.join(PATH, "school_subjects.txt"), "subject")
     ont.merge_dict("_locations", get_dict_from_list, os.path.join(PATH, "locations.txt"), None)
-    ont.merge_dict("_names", get_dict_from_list, os.path.join(PATH, "names.txt"), " names")
+    ont.merge_dict("_names", get_dict_from_list, os.path.join(PATH, "names.txt"), "names")
 
     # with open(os.path.join(PATH, "names.txt"), "r") as f:
     #     found = set()
@@ -167,8 +166,11 @@ if __name__ == '__main__':
     #                 print(line)
     #             found.add(line)
 
-    ont.add_dict(d)
-    ont.add_expressions(e)
+    file = open(os.path.join("data","_manual_ontology.json"), "r")
+    manual_ont = json.load(file)
+
+    ont.add_dict(manual_ont["ontology"])
+    ont.add_expressions(manual_ont["expressions"])
 
     ont = Ontology(ont.lemmatize())
 
