@@ -14,6 +14,7 @@ from emora_stdm.state_transition_dialogue_manager.utilities import HashableDict
 from emora_stdm.state_transition_dialogue_manager.macro import Macro
 from emora_stdm.state_transition_dialogue_manager.knowledge_base import KnowledgeBase
 from emora_stdm.state_transition_dialogue_manager.macros_common import *
+from emora_stdm.state_transition_dialogue_manager.natex_common import natex_macros_common
 from emora_stdm.state_transition_dialogue_manager.state import State
 from emora_stdm.state_transition_dialogue_manager.update_rules import UpdateRules
 from emora_stdm.state_transition_dialogue_manager.utilities import random_max, get_rmapping
@@ -105,7 +106,6 @@ class DialogueFlow:
         onte = ONTE(self._kb)
         kbe = KBE(self._kb)
         goal_exit_macro = GoalExit(self)
-        conjunction_macro = CheckVarsConjunction()
         self._macros = {
             'WN': WN(wordnet),
             'ONT': onte, 'ONTE': onte,
@@ -113,50 +113,21 @@ class DialogueFlow:
             'ONTN': ONTN(self._kb),
             'EXP': EXP(self._kb),
             'ONT_NEG': ONT_NEG(self._kb),
-            'NOT': NOT(),
-            'U': UnionMacro(),
-            'I': Intersection(),
-            'DIF': Difference(),
-            'SET': SetVars(),
-            'ALL': conjunction_macro,
-            'IF': conjunction_macro,
-            'ANY': CheckVarsDisjunction(),
-            'ISP': IsPlural(),
             'FPP': FirstPersonPronoun(self._kb),
             'TPP': ThirdPersonPronoun(self._kb),
             'PSP': PossessivePronoun(self._kb),
-            'EQ': Equal(),
             'GATE': Gate(self),
-            'UNSET': Unset(),
-            'CLR': Clear(),
-            'NER': NamedEntity(),
-            'POS': PartOfSpeech(),
-            'LEM': Lemma(),
-            'SCORE': Score(),
-            'TOKLIMIT': TokLimit(),
-            'AGREE': Agree(),
-            'DISAGREE': Disagree(),
-            'QUESTION': Question(),
-            'NEGATION': Negation(),
-            'IDK': DontKnow(),
-            'MAYBE': Maybe(),
-            'CONFIRM': Confirm(),
             'TRANSITION': Transition(self),
-            'UNX': Unexpected(),
-            'INT': Intent(),
-            'GEXT': goal_exit_macro,
             'GOAL': GoalPursuit(goal_exit_macro, self),
             'GCOM': GoalCompletion(self),
-            'GRET': GoalReturn(self),
-            'DEFAULT': Default(),
-            'VT': VirtualTransitions(self),
+            'GEXT': goal_exit_macro,
             'GSRET': SetGoalReturnPoint(),
-            'TARGET': Target(),
-            'CE': CanEnter(self),
-            'RW': Rewrite(),
-            'CONTRACTIONS': ExpandContractions(),
-            'SBS': ScoreBySimilarity()
+            'GRET': GoalReturn(self),
+            'VT': VirtualTransitions(self),
+            'CE': CanEnter(self)
         }
+        self._macros.update(macros_common_dict)
+        self._macros.update(natex_macros_common)
         if macros:
             self._macros.update(macros)
         self._rules = UpdateRules(vars=self._vars, macros=self._macros)
@@ -490,7 +461,7 @@ class DialogueFlow:
                 transition_transition_enter_vars.update(vars)
                 vars = transition_transition_enter_vars
                 if not gate_closed:
-                    transition_options.append((score, generation, transition, vars, gate_var_config, gate_target_id, tt_gate_var_config, tt_gate_target_id))
+                    transition_options.append((score, natex, generation, transition, vars, gate_var_config, gate_target_id, tt_gate_var_config, tt_gate_target_id))
             t2 = time()
             if debugging:
                 print('Transition {} evaluated in {:.5f}'.format(transition, t2-t1))
@@ -499,7 +470,12 @@ class DialogueFlow:
                 transition_items.append((natex, transition, score))
         self._transitions.clear()
         if transition_options:
-            score, response, transition, vars, gate_var_config, gate_target_id, tt_gate_var_config, tt_gate_target_id =\
+            if debugging:
+                print('Transition options: ------------')
+                for option in transition_options:
+                    print('{} {}: {}'.format(option[0], option[3][1], option[1]))
+                print('--------------------------------')
+            score, natex, response, transition, vars, gate_var_config, gate_target_id, tt_gate_var_config, tt_gate_target_id =\
                 random_max(transition_options, key=lambda x: x[0])
             if gate_var_config is not None:
                 self.gates()[gate_target_id].append(gate_var_config)
@@ -533,7 +509,7 @@ class DialogueFlow:
                 if debugging:
                     print('No valid system transitions found, going to default state...')
                 return self.system_transition(self.state(), debugging=debugging)
-            raise AssertionError('dialogue flow system transition found no valid options')
+            raise AssertionError('dialogue flow system transition found no valid options from state {}'.format(state))
 
 
     def user_transition(self, natural_language: str, state: Union[Enum, str, tuple], debugging=False):
@@ -623,7 +599,7 @@ class DialogueFlow:
                             gate_closed = True
                     del vars['__gate__']
                 if not gate_closed:
-                    transition_options.append((score, transition, vars, gate_var_config, gate_target_id))
+                    transition_options.append((score, natex, transition, vars, gate_var_config, gate_target_id))
             t2 = time()
             if debugging:
                 print('Transition {} evaluated in {:.5f}'.format(transition, t2-t1))
@@ -632,7 +608,12 @@ class DialogueFlow:
                 transition_items.append((natex, transition, score))
         self._transitions.clear()
         if transition_options:
-            score, transition, vars, gate_var_config, gate_target_id = random_max(transition_options, key=lambda x: x[0])
+            if debugging:
+                print('Transition options: ------------')
+                for option in transition_options:
+                    print('{} {}: {}'.format(option[0], option[2][1], option[1]))
+                print('--------------------------------')
+            score, natex, transition, vars, gate_var_config, gate_target_id = random_max(transition_options, key=lambda x: x[0])
             if gate_var_config is not None:
                 self.gates()[gate_target_id].append(gate_var_config)
             if debugging:
@@ -793,6 +774,11 @@ class DialogueFlow:
         source, target = module_source_target(source, target)
         source = State(source)
         target = State(target)
+        if isinstance(natex, str):
+            if speaker == Speaker.USER:
+                natex = NatexNLU(natex, macros=self._macros)
+            else:
+                natex = NatexNLG(natex, macros=self._macros)
         self._graph.arc_data(source, target, speaker)['natex'] = natex
 
     def transition_settings(self, source: Union[Enum, str, tuple], target: Union[Enum, str, tuple], speaker: Enum):
@@ -818,7 +804,7 @@ class DialogueFlow:
         state = State(state)
         return self._graph.data(state)['settings']
 
-    def add_global_nlu(self, state, nlu, score=0.5):
+    def add_global_nlu(self, state, nlu, score=0.5, post_nlu=None):
         state = module_state(state)
         state = State(state)
         if not self.has_state(state):
@@ -827,7 +813,10 @@ class DialogueFlow:
             state = ':'.join(state)
         if isinstance(nlu, list) or isinstance(nlu, set):
             nlu = '{' + ', '.join(nlu) + '}'
-        self._rules.add('{} ({})'.format(nlu, score), '#TRANSITION({}, {})'.format(state, score))
+        if post_nlu is None:
+            self._rules.add('{} ({})'.format(nlu, score), '#TRANSITION({}, {})'.format(state, score))
+        else:
+            self._rules.add('{} ({})'.format(nlu, score), '#TRANSITION({}, {}, {})'.format(state, score, post_nlu))
 
     def update_state_settings(self, state, **settings):
         state = module_state(state)
@@ -1029,11 +1018,10 @@ class DialogueFlow:
     def set_gates(self, gates):
         self._gates = gates
 
-    def load_global_nlu(self, transitions):
+    def load_global_nlu(self, transitions, default_score=0.5):
         for nlu, followup in transitions.items():
             if nlu == 'state':
                 continue
-            score = 0.5
             if isinstance(followup, str):
                 state = followup
             else:
@@ -1043,9 +1031,8 @@ class DialogueFlow:
                 else:
                     state = followup['state']
                 if 'score' in followup:
-                    score = followup['score']
-            nlu = nlu + ' #GEXT'
-            self.add_global_nlu(state, nlu, score)
+                    default_score = followup['score']
+            self.add_global_nlu(state, nlu, default_score, post_nlu='`/.*/ #GEXT`')
         self.load_transitions(transitions, Speaker.USER)
 
     def load_update_rules(self, rules_dict):
