@@ -6,7 +6,7 @@ from emora_stdm.state_transition_dialogue_manager.memory import Memory
 from emora_stdm.state_transition_dialogue_manager.utilities import HashableSet, HashableDict, ConfigurationDict
 from emora_stdm.state_transition_dialogue_manager.natex_nlg import NatexNLG
 from emora_stdm.state_transition_dialogue_manager.natex_nlu import NatexNLU
-from emora_stdm.state_transition_dialogue_manager.natex_common import *
+# from emora_stdm.state_transition_dialogue_manager.natex_common import *
 from typing import Union, Set, List, Dict, Callable, Tuple, NoReturn, Any
 import nltk
 from nltk.sentiment.vader import SentimentIntensityAnalyzer
@@ -258,6 +258,44 @@ def _assignment_to_var_val(arg):
     var, val = match.groups()
     return var, val
 
+def _get_terms(arg, operator, vars):
+    t1, t2 = arg.split(operator)
+    if t1[0] == '$':
+        var = t1[1:]
+        t1 = vars[var] if var in vars else 'None'
+    if t2[0] == '$':
+        var = t2[1:]
+        t2 = vars[var] if var in vars else 'None'
+    return t1, t2
+
+def _term_op_term(arg, vars):
+    if '<=' in arg:
+        operator = '<='
+        t1, t2 = _get_terms(arg, operator, vars)
+        return t1 <= t2
+    elif '>=' in arg:
+        operator = '>='
+        t1, t2 = _get_terms(arg, operator, vars)
+        return t1 >= t2
+    elif '!=' in arg:
+        operator = '!='
+        t1, t2 = _get_terms(arg, operator, vars)
+        return t1 != t2
+    elif '<' in arg:
+        operator = '<'
+        t1, t2 = _get_terms(arg, operator, vars)
+        return t1 < t2
+    elif '>' in arg:
+        operator = '>'
+        t1, t2 = _get_terms(arg, operator, vars)
+        return t1 > t2
+    elif '=' in arg:
+        operator = '='
+        t1, t2 = _get_terms(arg, operator, vars)
+        return t1 == t2
+    else:
+        return False
+
 class SetVars(Macro):
     def run(self, ngrams: Ngrams, vars: Dict[str, Any], args: List[Any]):
         for arg in args:
@@ -268,17 +306,14 @@ class SetVars(Macro):
 class CheckVarsConjunction(Macro):
     def run(self, ngrams: Ngrams, vars: Dict[str, Any], args: List[Any]):
         for arg in args:
-            var, val = _assignment_to_var_val(arg)
-            if (var not in vars and val != 'None') or (var in vars and vars[var] != val):
+            if not _term_op_term(arg, vars):
                 return False
         return True
 
-
 class CheckVarsDisjunction(Macro):
     def run(self, ngrams: Ngrams, vars: Dict[str, Any], args: List[Any]):
         for arg in args:
-            var, val = _assignment_to_var_val(arg)
-            if (val == 'None' and var not in vars) or (var in vars and vars[var] == val):
+            if _term_op_term(arg, vars):
                 return True
         return False
 
@@ -340,6 +375,13 @@ class PossessivePronoun(Macro):
         else:
             return 'their'
 
+
+class Increment(Macro):
+
+    def run(self, ngrams: Ngrams, vars: Dict[str, Any], args: List[Any]):
+        vars[args[0]] += 1
+
+
 class Equal(Macro):
     def run(self, ngrams: Ngrams, vars: Dict[str, Any], args: List[Any]):
         args = _process_args_set(args, vars)
@@ -468,10 +510,13 @@ class Score(Macro):
 
 class TokLimit(Macro):
     def run(self, ngrams: Ngrams, vars: Dict[str, Any], args: List[Any]):
-        if len(ngrams.text().split()) <= int(args[0]):
-            return True
-        else:
-            return False
+        if ngrams:
+            if len(ngrams.text().split()) <= int(args[0]):
+                return True
+            else:
+                return False
+
+
 
 class Transition(Macro):
     """
@@ -485,10 +530,14 @@ class Transition(Macro):
             score = float(args[1])
         else:
             score = 0.5
+        if len(args) > 2:
+            natex = NatexNLU(args[2], macros=self.dialogue_flow._macros)
+        else:
+            natex = NatexNLU('/.*/', macros=self.dialogue_flow._macros)
         target = args[0]
         vars['__converged__'] = 'True'
         self.dialogue_flow.dynamic_transitions().append(
-            (NatexNLU('/.*/'),
+            (natex,
              (self.dialogue_flow.state(), target, self.dialogue_flow.speaker()),
              score))
 
@@ -900,13 +949,33 @@ class CheckNotComponent(Macro):
         return True
 
 
+_conjunction_macro = CheckVarsConjunction()
 
-
-
-
-
-
-
+macros_common_dict = {
+    'RW': Rewrite(),
+    'CONTRACTIONS': ExpandContractions(),
+    'SBS': ScoreBySimilarity(),
+    'TARGET': Target(),
+    'DEFAULT': Default(),
+    'INT': Intent(),
+    'UNSET': Unset(),
+    'CLR': Clear(),
+    'NER': NamedEntity(),
+    'POS': PartOfSpeech(),
+    'LEM': Lemma(),
+    'SCORE': Score(),
+    'TOKLIMIT': TokLimit(),
+    'EQ': Equal(),
+    'NOT': NOT(),
+    'U': UnionMacro(),
+    'I': Intersection(),
+    'DIF': Difference(),
+    'SET': SetVars(),
+    'ALL': _conjunction_macro,
+    'IF': _conjunction_macro,
+    'ANY': CheckVarsDisjunction(),
+    'ISP': IsPlural(),
+}
 
 
 
